@@ -70,6 +70,12 @@
 #    define _CAIRO_SURFACE_CLASSNAME Win32CairoSurface
 #    include "cairo/Win32CairoSurface.h"
 #  endif /* USE_GLITZ */
+#elif BUILD_SERVER == SERVER_wayland
+#  include "wayland/WaylandServer.h"
+#  include "cairo/CairoGState.h"
+#  include "cairo/WaylandCairoSurface.h"
+#  define _CAIRO_GSTATE_CLASSNAME CairoGState
+#  define _CAIRO_SURFACE_CLASSNAME WaylandCairoSurface
 #else
 #  error Invalid server for Cairo backend : non implemented
 #endif /* BUILD_SERVER */
