@@ -1449,7 +1449,7 @@ HBITMAP GSCreateBitmap(HDC hDC, NSInteger pixelsWide, NSInteger pixelsHigh,
       return NULL;
     }
 
-  win = (WIN_INTERN *)GetWindowLong((HWND)window, GWL_USERDATA);
+  win = (WIN_INTERN *)GetWindowLongPtr((HWND)window, GWLP_USERDATA);
   if (win && win->useHDC)
     {
       hDC = win->hdc;
@@ -1482,7 +1482,7 @@ HBITMAP GSCreateBitmap(HDC hDC, NSInteger pixelsWide, NSInteger pixelsHigh,
     }
 
   [self restoreStyle: hDC];
-  win = (WIN_INTERN *)GetWindowLong((HWND)window, GWL_USERDATA);
+  win = (WIN_INTERN *)GetWindowLongPtr((HWND)window, GWLP_USERDATA);
   if (win && !win->useHDC)
     ReleaseDC((HWND)window, hDC);
 }
