@@ -47,14 +47,14 @@
 /* Size of the dragged window */
 #define	DWZ	48
 
-#define XDPY  [XGServer currentXDisplay]
+#define XDPY  [XGServer xDisplay]
 
 #define SLIDE_TIME_STEP   .02   /* in seconds */
 #define SLIDE_NR_OF_STEPS 20  
 
 #define	DRAGWINDEV [XGServer _windowWithTag: [_window windowNumber]]
 #define	XX(P)	(P.x)
-#define	XY(P)	(DisplayHeight(XDPY, DRAGWINDEV->screen) - P.y)
+#define	XY(P)	([(XGServer *)GSCurrentServer() xScreenSize].height - P.y)
 
 @interface XGRawWindow : NSWindow
 @end
